@@ -8,10 +8,13 @@ extends 'Webservice::InterMine::Query::Core';
 with(
     'Webservice::InterMine::Query::Roles::Templated',
     'Webservice::InterMine::Query::Roles::Runnable',
-    'Webservice::InterMine::Query::Roles::Serviced',
+    'Webservice::InterMine::Query::Roles::TemplateParameters',
+    'Webservice::InterMine::Role::Serviced',
+    'Webservice::InterMine::Role::Showable',
     'Webservice::InterMine::Query::Roles::ReadInAble',
     'Webservice::InterMine::Query::Roles::WriteOutAble',
     'Webservice::InterMine::Query::Roles::ExtendedQuery',
+    'Webservice::InterMine::Query::Roles::Listable',
 );
 
 sub _build_handler {
